@@ -53,17 +53,17 @@ get_tag <- function(file, tagname) {
   file[[1]][[tagname]]
 }
 
-add_tag <- function(file, tag) {
+add_tag <- function(file, tag, overwrite = FALSE) {
   if (is.null(tag)) return()
   stopifnot(is.rd_file(file))
 
   if (!is.rd_tag(tag) && is.list(tag)) {
-    return(lapply(tag, add_tag, file = file))
+    return(lapply(tag, add_tag, file = file, overwrite = overwrite))
   }
   stopifnot(is.rd_tag(tag))
 
   existing <- file[[1]][[tag$tag]]
-  if (is.null(existing)) {
+  if (is.null(existing) || overwrite) {
     file[[1]][[tag$tag]] <- tag
   } else {
     file[[1]][[tag$tag]] <- merge(existing, tag)[[1]]
